@@ -455,9 +455,10 @@ class ServersTest(utils.FixturedTestCase):
         self.assertEqual('sample-server', server.name)
 
         self.assertRaises(exceptions.NoUniqueMatch, self.cs.servers.find,
-                          flavor={"id": 1, "name": "256 MB Server"})
+                          flavor={"id": 1, "name": "256 MiB Server"})
 
-        sl = self.cs.servers.findall(flavor={"id": 1, "name": "256 MB Server"})
+        sl = self.cs.servers.findall(flavor={"id": 1,
+                                             "name": "256 MiB Server"})
         self.assert_request_id(sl, fakes.FAKE_REQUEST_ID_LIST)
         self.assertEqual([1234, 5678, 9012], [s.id for s in sl])
 
@@ -715,7 +716,7 @@ class ServersTest(utils.FixturedTestCase):
         s = self.cs.servers.get(1234)
         password = s.get_password('novaclient/tests/unit/idfake.pem')
         self.assert_request_id(password, fakes.FAKE_REQUEST_ID_LIST)
-        self.assertEqual(b'FooBar123', password)
+        self.assertEqual('FooBar123', password)
         self.assert_called('GET', '/servers/1234/os-server-password')
 
     def test_get_password_without_key(self):
